@@ -1,5 +1,5 @@
 package Job::Machine::DB;
-$Job::Machine::DB::VERSION = '0.20';
+$Job::Machine::DB::VERSION = '0.21';
 use strict;
 use warnings;
 use Carp qw/croak confess/;
@@ -26,7 +26,7 @@ sub new {
 sub serializer {
 	my ($self) = @_;
 	my $args = $self->{serializer_args} || {};
-	$args->{serializer} ||= $self->{serializer} // 'Sereal';
+	$args->{serializer} ||= $self->{serializer} || 'Sereal';
 	return $self->{serialize} ||= Data::Serializer->new(%$args);
 }
 
@@ -375,7 +375,7 @@ Job::Machine::DB
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 NAME
 
